<h1> crime     <a href="https://pypi.org/project/crime/" alt="Version"> <img src="https://img.shields.io/pypi/v/crime.svg" /></a> </h1>

**View Full Documentation [Here](https://github.com/ryayoung/crime)**

<br>

## Install & Use

Must have python 3.9+

```
pip install crime
```

```py
import crime as cr
```

<br>

